*[CLI]: Command-Line Interface
*[SDK]: Software Development Kit
*[API]: Application Programming Interface
*[YAML]: YAML Ain't Markup Language — a human-readable data format used for configuration
*[TOML]: Tom's Obvious Minimal Language — a configuration file format
*[CI]: Continuous Integration
*[CI/CD]: Continuous Integration and Continuous Deployment
*[TTY]: Terminal — an interactive shell session
*[DNS]: Domain Name System
*[HTTPS]: Hypertext Transfer Protocol Secure
*[MCP]: Model Context Protocol
*[LLM]: Large Language Model
*[TUI]: Terminal User Interface
